@@ -25,9 +25,9 @@
 
 #include "akonadiserializer.h"
 
-#include <Akonadi/Collection>
-#include <Akonadi/EntityDisplayAttribute>
-#include <Akonadi/Item>
+#include <AkonadiCore/Collection>
+#include <AkonadiCore/EntityDisplayAttribute>
+#include <AkonadiCore/Item>
 #include <Akonadi/Notes/NoteUtils>
 #include <KCalCore/Todo>
 #include <KMime/Message>
@@ -215,9 +215,9 @@ void Serializer::updateTaskFromItem(Domain::Task::Ptr task, Item item)
     task->setTitle(todo->summary());
     task->setText(todo->description());
     task->setDone(todo->isCompleted());
-    task->setDoneDate(todo->completed().dateTime());
-    task->setStartDate(todo->dtStart().dateTime());
-    task->setDueDate(todo->dtDue().dateTime());
+    task->setDoneDate(todo->completed().dateTime().toUTC());
+    task->setStartDate(todo->dtStart().dateTime().toUTC());
+    task->setDueDate(todo->dtDue().dateTime().toUTC());
     task->setProperty("itemId", item.id());
     task->setProperty("parentCollectionId", item.parentCollection().id());
     task->setProperty("todoUid", todo->uid());
@@ -351,7 +351,7 @@ void Serializer::promoteItemToProject(Akonadi::Item item)
 
     auto todo = item.payload<KCalCore::Todo::Ptr>();
     todo->setRelatedTo(QString());
-    todo->setCustomProperty("Zanshin", "Project", "1");
+    todo->setCustomProperty("Zanshin", "Project", QStringLiteral("1"));
 }
 
 void Serializer::clearItem(Akonadi::Item *item)
@@ -489,7 +489,7 @@ Item Serializer::createItemFromProject(Domain::Project::Ptr project)
     auto todo = KCalCore::Todo::Ptr::create();
 
     todo->setSummary(project->name());
-    todo->setCustomProperty("Zanshin", "Project", "1");
+    todo->setCustomProperty("Zanshin", "Project", QStringLiteral("1"));
 
     if (project->property("todoUid").isValid()) {
         todo->setUid(project->property("todoUid").toString());
